@@ -75,6 +75,14 @@ from notify.utils import DummyReference
 
 #-- Base binding class -----------------------------------------------
 
+# Note on (not) using `functools.partial' in Python 2.5 and up.  I have investigated the
+# possibility, but it doesn't seem useful.  It gave no visible speed up even on
+# `emission.EmissionBenchmark1' (which uses functional handlers.)  Besides, using
+# `partial' would complicate the code, because it would bind the object strongly (hence
+# unusable for `WeakBinding' below), won't compare as needed by itself and so on.
+#
+# Conclusion: let's not use it at all.
+
 class Binding (object):
 
     """
@@ -154,7 +162,7 @@ class Binding (object):
                            iterable.
         """
 
-        if arguments is not ():
+        if arguments:
             return cls (callable_object, arguments)
         else:
             if not callable (callable_object):
@@ -263,17 +271,16 @@ class Binding (object):
             if isinstance (other, Binding):
                 return self._get_arguments () == other._get_arguments ()
             else:
-                return self._get_arguments () is ()
+                return not self._get_arguments ()
+
+        elif isinstance (other, FunctionType):
+            return (    self._get_function () is other
+                    and self._get_object   () is None
+                    and self._get_class    () is None
+                    and not self._get_arguments ())
 
         else:
-            if isinstance (other, FunctionType):
-                return (self.im_func is other
-                        and self.im_self is None
-                        and self.im_class is None
-                        and self.im_args is ())
-            else:
-                return NotImplemented
-
+            return NotImplemented
 
 
     def __ne__(self, other):
@@ -291,6 +298,22 @@ class Binding (object):
             return NotImplemented
 
 
+    def __hash__(self):
+        _class    = self._get_class     ()
+        object    = self._get_object    ()
+        arguments = self._get_arguments ()
+
+        if _class is not None or object is not None:
+            _hash = hash (MethodType (self._get_function (), object, _class))
+        else:
+            _hash = id (self._get_function ())
+
+        if arguments:
+            return _hash ^ hash (arguments)
+        else:
+            return _hash
+
+
     def __nonzero__(self):
         """
         C{True} if binding is in its initial and fully functional state.  This method
@@ -353,6 +376,48 @@ class Binding (object):
                                 """))
 
 
+    def __repr__(self):
+        return self.__to_string ('%s.%s' % (self.__module__, self.__class__.__name__), True)
+
+    def __str__(self):
+        return self.__to_string (self.__class__.__name__, False)
+
+    def __to_string (self, class_name, strict):
+        if strict:
+            formatter = repr
+        else:
+            formatter = str
+
+        _class    = self._get_class     ()
+        function  = self._get_function  ()
+        arguments = self._get_arguments ()
+
+        if isinstance (function, FunctionType):
+            function_description = function.__name__
+        else:
+            function_description = formatter (function)
+
+        description = '%s at 0x%x' % (class_name, id (self))
+
+        if _class is not None:
+            object = self._get_object ()
+
+            if object is not None:
+                description = ('bound %s for %s.%s of %s'
+                               % (description, _class.__name__, function_description,
+                                  formatter (object)))
+            else:
+                description = ('unbound %s for %s.%s'
+                               % (description, _class.__name__, function_description))
+        else:
+            description = '%s for %s' % (description, function_description)
+
+        if arguments:
+            return ('<%s (%s, ...)>'
+                    % (description, ', '.join ([formatter (argument) for argument in arguments])))
+        else:
+            return '<%s>' % description
+
 
 BindingCompatibleTypes = (MethodType, Binding)
 """
@@ -392,7 +457,7 @@ class WeakBinding (Binding):
     @see:  RaisingWeakBinding
     """
 
-    __slots__ = ('_WeakBinding__callback')
+    __slots__ = ('_WeakBinding__callback', '_WeakBinding__hash')
 
 
     def __init__(self, callable_object, arguments = (), callback = None):
@@ -440,10 +505,12 @@ class WeakBinding (Binding):
         else:
             self._object = _NONE_REFERENCE
 
+        self.__hash = None
+
 
     def wrap (cls, callable_object, arguments = (), callback = None):
         # Inherit documentation somehow?
-        if (arguments is not ()
+        if (arguments
             or (    isinstance (callable_object, BindingCompatibleTypes)
                 and not isinstance (callable_object, WeakBinding)
                 and callable_object.im_self is not None)):
@@ -517,6 +584,18 @@ class WeakBinding (Binding):
             callback (reference)
 
 
+    def __hash__(self):
+        if self.__hash is None:
+            if bool (self):
+                self.__hash = super (WeakBinding, self).__hash__()
+            else:
+                raise TypeError (("%s's object had been garbage-collected"
+                                  "before first call to __hash__()")
+                                 % self.__class__.__name__)
+
+        return self.__hash
+
+
     def __nonzero__(self):
         """
         C{True} if method’s object hasn’t been garbage-collected.  More precisely, C{True}
